@@ -242,7 +242,7 @@ class Connection(object):
         """
         self.job_source = name
 
-    def search(self, query='', date_start=None, date_finish=None, fields=None, size=10, query_size=10):
+    def search(self, query='', date_start=None, date_finish=None, fields=None, size=0, query_size=10):
         """
         Performs a block search against the Shooju API
 
@@ -258,7 +258,7 @@ class Connection(object):
         data = self._shooju_api.search_series(query, date_start, date_finish, size, query_size, fields)
         return self._process_search_response(data)
 
-    def scroll(self, query='', date_start=None, date_finish=None, fields=None, size=10):
+    def scroll(self, query='', date_start=None, date_finish=None, fields=None, size=0):
         """
         Performs a scroll search. Function is a generator, it returns one series at a time
 
@@ -907,6 +907,8 @@ class RemoteJob(object):
         self._pre_hooks = pre_hooks or []
         self._post_hooks = post_hooks or []
 
+        self._remove = defaultdict(lambda: {'fields': False, 'points': False})
+
     @property
     def job_id(self):
         return self._job_id
@@ -990,6 +992,16 @@ class RemoteJob(object):
         for series, values in self._values.iteritems():
             #here we will construct a BULK API call
             tmp_dict = {"type": "POST", "id": series, "body": values}
+            if series in self._remove:
+                if self._remove[series]['points'] and self._remove[series]['fields']:
+                    remove = 'all'
+                elif self._remove[series]['points']:
+                    remove = 'series'
+                else:
+                    remove = 'fields'
+                values['keep_only'] = remove
+
+
             bulk_data.append(tmp_dict)
 
         #we send the bulk data at once
@@ -1001,9 +1013,29 @@ class RemoteJob(object):
                 # always flush cache
                 self._values = {}
                 self._cur_batch_size = 0
+        # resetting _remove
+        self._remove = defaultdict(lambda: {'fields': False, 'points': False})
         self._run_post_submit_hooks(response)
         return True
 
+    def remove_points(self, series_id):
+        """
+        Removes all points from the series before adding the new points. This will be set until a submit is triggered
+        or submit is called explicitly.
+
+        :param series_id: series id to set the remove points flag
+        """
+        self._remove[series_id]['points'] = True
+
+    def remove_fields(self, series_id):
+        """
+        Removes fields from the series before adding the new fields. This will be set until a submit is triggered
+        or submit is called explicitly.
+
+        :param series_id: series id to set the remove points flag
+        """
+        self._remove[series_id]['fields'] = True
+
     def add_post_submit_hook(self, fn):
         """
         Adds a hook that will be run after the cache is submitted to shooju
